==> zither-1.1.15.tar.gz: zither_prj/apollon/block_data_delete.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(3)){
   exit;
   }



echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

$BNAME = enco($_GET["BNAME"]);
$GEN = enco($_GET["GEN"]);

print($version_name);
print("\n");
print(date("Y m d g i s A"));
print("\n");

$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

if(0 == strlen($BNAME)){
   print("NG NOT block name");
   exit;
   }

$result=pg_query($conn, "select * from userblock where bname='$BNAME'");
if(!$result){
   print("NG bud query set\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
    $CNAMEDEF = enco_rtrim(pg_fetch_Result($result, $s, cname));
    print("OK ư֥åϿƤ륯饤Ȥ $CNAMEDEF Ǥ\n");
    }
else{
   print("NG ư֥åƻ륯饤ȤȽǽޤ");
   exit;
   }

$result = pg_query($conn, "select * from userblock where bname='$BNAME'");
if(!$result){
   print("bud query set\n");
   exit;
   }
$num = pg_num_rows($result);
if($num <= 0){
   print("NG ֥å̾DBˤޤ\n");
   exit;
   }
if($num > 0){
   print("ƻ֥åޤ\n");
   $result = pg_query($conn, "delete from userblock where bname='$BNAME'");
   if(!$result){
      print("NG ޤ\n");
      exit;
      }
   print("Ϣƻޤ\n");
   $result = pg_query($conn, "delete from monitor where free4='$BNAME'");
   if(!$result){
      print("NG ޤ\n");
      exit;
      }
   pg_free_result($result);
   }


// --- list file upload --- // 
list_file_upload($CNAMEDEF, $GEN);



pg_free_result($result);
pg_Close($conn);

?>

</pre>
</body>
</html>

==> zither-1.1.17.tar.gz: zither_prj/apollon/block_data_delete.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(3)){
   exit;
   }



echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

$BNAME = enco($_GET["BNAME"]);
$GEN = enco($_GET["GEN"]);

print($version_name);
print("\n");
print(date("Y m d g i s A"));
print("\n");

$conn = db_connect();
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

if(0 == strlen($BNAME)){
   print("NG NOT block name");
   exit;
   }

$result=db_query($conn, "select * from userblock where bname='$BNAME'");
if(!$result){
   print("NG bud query set\n");
   exit;
   }
$num = db_num_rows($result);
if($num > 0){
    $CNAMEDEF = enco_rtrim(db_fetch_Result($result, $s, cname));
    print("OK ư֥åϿƤ륯饤Ȥ $CNAMEDEF Ǥ\n");
    }
else{
   print("NG ư֥åƻ륯饤ȤȽǽޤ");
   exit;
   }

$result = db_query($conn, "select * from userblock where bname='$BNAME'");
if(!$result){
   print("bud query set\n");
   exit;
   }
$num = db_num_rows($result);
if($num <= 0){
   print("NG ֥å̾DBˤޤ\n");
   exit;
   }
if($num > 0){
   print("ƻ֥åޤ\n");
   $result = db_query($conn, "delete from userblock where bname='$BNAME'");
   if(!$result){
      print("NG ޤ\n");
      exit;
      }
   print("Ϣƻޤ\n");
   $result = db_query($conn, "delete from monitor where free4='$BNAME'");
   if(!$result){
      print("NG ޤ\n");
      exit;
      }
   db_free_result($result);
   }


// --- list file upload --- // 
list_file_upload($CNAMEDEF, $GEN);



db_free_result($result);
db_Close($conn);

?>

</pre>
</body>
</html>
